Method: BootstrapForm::Aliasing#bootstrap_method_alias

Defined in:
lib/bootstrap_form/aliasing.rb

#bootstrap_method_alias(target) {|aliased_target, punctuation| ... } ⇒ Object

This code is copied and pasted from ActiveSupport, but with :bootstrap hardcoded as the feature name, and with the deprecation warning removed.

Yields:

  • (aliased_target, punctuation)


11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/bootstrap_form/aliasing.rb', line 11

def bootstrap_method_alias(target)
  feature = :bootstrap

  # Strip out punctuation on predicates, bang or writer methods since
  # e.g. target?_without_feature is not a valid method name.
  aliased_target, punctuation = target.to_s.sub(/([?!=])$/, ''), $1
  yield(aliased_target, punctuation) if block_given?

  with_method = "#{aliased_target}_with_#{feature}#{punctuation}"
  without_method = "#{aliased_target}_without_#{feature}#{punctuation}"

  alias_method without_method, target
  alias_method target, with_method

  case
  when public_method_defined?(without_method)
    public target
  when protected_method_defined?(without_method)
    protected target
  when private_method_defined?(without_method)
    private target
  end
end